// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/*
 * The module provides autocomplete for the question idnumber form field.
 *
 * @module    filter_embedquestion/questionid_choice_updater
 * @package   filter_embedquestion
 * @copyright 2018 The Open University
 * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */
define(['jquery', 'core/ajax'], function($, Ajax) {
    var t = {
        /**
         * Initialise the handling.
         */
        init: function() {
            $('select#id_category').on('change', t.categoryChanged);
            t.lastCategory = null;
            $('button#id_add_to_editor').on('click', t.testChanged);

        },

        /**
         * Used to track when the category really changes.
         */
        lastCategory: null,

        /**
         * Source of data for Ajax element.
         */
        categoryChanged: function() {
            if ($('select#id_category').val() === t.lastCategory) {
                return;
            }

            //M.util.js_pending('mod_fastassignment_get_categories');
            $('.mod_fastassignment_get_categories').html('Loading...');
            t.lastCategory = $('select#id_category').val();

            if (t.lastCategory === '') {
                t.updateChoices([]);
            } else {
                Ajax.call([{
                    methodname: 'mod_fastassignment_get_tasks_choices',
                    args: {category: t.lastCategory}
                }])[0].done(t.updateChoices);
            }
        },
         /**
         * Source of data for Ajax element.
         */
          testChanged: function() {
            if ($('select#id_test').val() === t.lastCategory) {
                return;
            }

            //M.util.js_pending('mod_fastassignment_get_categories');
            $('.mod_fastassignment_get_test_info').html('Loading...');
            t.test = $('select#id_test').val();

            if (t.test === '') {
                t.addIntoEditor([]);
            } else {
                Ajax.call([{
                    methodname: 'mod_fastassignment_get_tasks_info',
                    args: {test: t.test}
                }])[0].done(t.addIntoEditor);
            }
        },

        /**
         * Update the contents of the Question select with the results of the AJAX call.
         *
         * @param {Array} response - array of options, each has fields value and label.
         */
        updateChoices: function(response) {
            var select = $('select#id_test');
            select.empty();
            $(response).each(function(index, option) {
                select.append('<option value="' + option.value + '">' + option.label + '</option>');
            });
            //M.util.js_complete('mod_fastassignment_get_categories');
            $('.mod_fastassignment_get_categories').html('');
        },

        addIntoEditor: function(response) {
            let dataToSubmit = response.test_question;
            let test_name = response.test_name;
            let test_image = response.test_image;
            if(test_image) {
              let ieltsChart = `<img src="${test_image}" alt='${test_name}' width='400'/>`;
              dataToSubmit = dataToSubmit + "<p>"+ ieltsChart + "</p>";
            }
            $("#id_introeditoreditable").html('');
            $("#id_introeditoreditable").append(dataToSubmit);
            //M.util.js_complete('mod_fastassignment_get_categories');
            $('.mod_fastassignment_get_test_info').html('');
        }
    };
    return t;
});